@@ -16,11 +16,11 @@
 
 # TAP support:
 #  - handling of "ambiguous" TODO and SKIP directives
-# See also related test 'tap-todo-skip-together.test'.
+# See also related test 'tap-todo-skip-together.sh'.
 
 . ./defs || exit 1
 
-. "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
+. tap-setup.sh
 
 cat > all.test <<END
 1..6
