@@ -54,7 +54,7 @@ fi
 cat > Makefile.am << 'END'
 TESTS = all.test
 END
-. "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
+. tap-setup.sh
 
 cat > all.test <<'END'
 #! /bin/sh
